# -*- coding: UTF-8 -*-

from functools import wraps


#  generates an identifier for the callables
def identifier(f):
    return "%s.%s" % (f.__module__.split('.')[0], f.__name__)

api_registry = {}


def api_handler(name):
    if name == 'help':
        return {k: v.__doc__ for k, v in api_registry.items()}
    if name in api_registry:
        return api_registry[name]

    def not_found(*args, **kwargs):
        return {
            'state': 404,
            'exception': "API callable '%s' not found" % name
        }

    return not_found


def api_callable(f):
    """
    Registers the given function as an API callable and puts the results
    in a dictionnary along with a API state..
    """
    # TODO: the decorator could log the exception in some logger
    @wraps(f)
    def wrapper(*args, **kwargs):
        try:
            data = f(*args, **kwargs)
            return {
                'state': 0,
                'data': data
            }
        except Exception as e:
            return {
                'state': 1,
                'exception': str(e)
            }

    # callables are registered as module_name.callable.name
    # throw an exception if two callables are going to be stored
    # under the same name
    if identifier(f) in api_registry:
        raise Exception("%s already registered" % identifier(f))

    api_registry[identifier(f)] = wrapper

    # instead of returning the wrapper, we return the function itself
    # this is handy since we need the return of the functions within the
    # api engines
    return f


@api_callable
def index():
    """This is an index docstring"""
    return {k: v.__doc__ for k, v in api_registry.items()}
