# -*- coding: UTF-8 -*-
# pylint:disable=invalid-name

"""Module with methods for common tasks"""

import logging
import logging.handlers
import os
import sys

from django.conf import settings
from symonitoring_rpcserver.log import LogFormatter

_SETUP_DONE = False


def _setup_logger(level, stderr=False):
    """Sets up a default logger"""
    global _SETUP_DONE  # pylint: disable=global-statement
    if _SETUP_DONE:
        return
    logger_name = settings.AMQ_SETTINGS['app_name']
    root = logging.getLogger()
    _lg = root.getChild(logger_name)

    if (
            sys.platform.startswith("mac") or
            sys.platform.startswith("darwin")
    ):  # pragma: no cover
        root_handler = logging.handlers.SysLogHandler(
            facility=logging.handlers.SysLogHandler.LOG_LOCAL0,
            address='/var/run/syslog'
        )
        lg_handler = logging.handlers.SysLogHandler(
            facility=logging.handlers.SysLogHandler.LOG_LOCAL0,
            address='/var/run/syslog'
        )
    else:
        root_handler = logging.handlers.SysLogHandler(
            facility=logging.handlers.SysLogHandler.LOG_LOCAL0,
            address='/dev/log'
        )
        lg_handler = logging.handlers.SysLogHandler(
            facility=logging.handlers.SysLogHandler.LOG_LOCAL0,
            address='/dev/log'
        )

    formatter = LogFormatter(
        color=False,
        fmt=('{0}[PID {1}]: [%(levelname)1.1s %(asctime)s '
             '%(module)s:%(lineno)d] '
             '%(message)s').format(logger_name, os.getpid())
    )
    root.addHandler(root_handler)
    _lg.addHandler(lg_handler)
    if stderr:
        stderr_formatter = LogFormatter(
            color=True
        )
        stderr_handler = logging.StreamHandler(sys.stderr)
        stderr_handler.setFormatter(stderr_formatter)
        _lg.addHandler(stderr_handler)
        root.addHandler(stderr_handler)
    for handler in _lg.handlers:
        handler.setFormatter(formatter)
    _lg.setLevel(level)
    root.setLevel(level)
    _SETUP_DONE = True
    return _lg

lg = _setup_logger(logging.DEBUG)
