# -*- coding: UTF-8 -*-

"""Helper functions for determining the current Icinga state"""

from django.conf import settings
from mk_livestatus import Socket


class NotFound(Exception):
    """Signalize that an object in mk_livestatus was not found"""
    pass


def get_host_state(host):
    """Return the current host state according to Icinga"""
    live_socket = Socket(settings.LIVE_SOCKET_PATH)
    host_query = live_socket.hosts
    host_query.columns('state')
    host_query.filter('name = {}'.format(host.hostname))
    try:
        icinga_host = host_query.call()[0]
    except IndexError:
        raise NotFound('Host "{}" does not exist in Icinga'.format(
            host.hostname
        ))
    return icinga_host['state']


def get_service_state(instance):
    """Return the current service state according to Icinga"""
    live_socket = Socket(settings.LIVE_SOCKET_PATH)
    service_query = live_socket.services
    service_query.columns('state')
    service_query.filter(
        'host_name = {}'.format(
            instance.hostserviceid.hostid.hostname
        )
    )
    service_query.filter(
        'description = {}'.format(
            instance.display_name
        )
    )
    try:
        icinga_service = service_query.call()[0]
    except IndexError:
        raise NotFound('Service does not exist')
    return icinga_service['state']
