"""
Django settings for symonitoring_rpcserver project.

For more information on this file, see
https://docs.djangoproject.com/en/1.7/topics/settings/

For the full list of settings and their values, see
https://docs.djangoproject.com/en/1.7/ref/settings/
"""

# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
import os
BASE_DIR = os.path.dirname(os.path.dirname(__file__))

# Use pymysql as mysqldb
# the maintainer of pymsql keeps 100% mysqldb compatibility
# and runs unittests against django
try:
    import pymysql
    pymysql.install_as_MySQLdb()
except ImportError:  # pragma: no cover
    pass

# System import
try:
    import configparser as cp
except ImportError:
    import ConfigParser as cp

SETTINGS_FILE     = '/var/lib/symonitoring/config/rpc.ini'
C                 = cp.ConfigParser()
C.read(SETTINGS_FILE)

# Quick-start development settings - unsuitable for production
# See https://docs.djangoproject.com/en/1.7/howto/deployment/checklist/

# SECURITY WARNING: keep the secret key used in production secret!
SECRET_KEY = 'wq85m^gpcylesr1zr@x!41c&&l)uu$@due=&#+%^#_v2u_u&ki'

# SECURITY WARNING: don't run with debug turned on in production!
DEBUG = False

TEMPLATE_DEBUG = False

ALLOWED_HOSTS = []


# Application definition

INSTALLED_APPS = (
    'django_nose',
    'symonitoring_model',
    'symonitoring_bpe',
    'symonitoring_reporting',
    'django.contrib.contenttypes',
)

MIDDLEWARE_CLASSES = (
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

ROOT_URLCONF = 'symonitoring_rpcserver.urls'

WSGI_APPLICATION = 'symonitoring_rpcserver.wsgi.application'


# Database
# https://docs.djangoproject.com/en/1.7/ref/settings/#databases

DATABASES = {
    'default' : {
        'ENGINE'   : 'django.db.backends.mysql',
        'NAME'     : C.get('DATABASE', 'NAME'),
        'USER'     : C.get('DATABASE', 'USER'),
        'PASSWORD' : C.get('DATABASE', 'PASSWORD'),
        'HOST'     : C.get('DATABASE', 'HOST'),
    }
}
if 'MYSQL_PWD' in os.environ:
    DATABASES['default']['PASSWORD'] = os.environ['MYSQL_PWD']

# Internationalization
# https://docs.djangoproject.com/en/1.7/topics/i18n/

LANGUAGE_CODE = 'en-us'

TIME_ZONE = 'UTC'

USE_I18N = True

USE_L10N = True

USE_TZ = True


# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/1.7/howto/static-files/

STATIC_URL = '/static/'

TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'

NOSE_ARGS = [
    '--with-coverage',
    '--cover-package=symonitoring_bpe',
    '--cover-erase',
    '--logging-level=WARNING',
]

AMQ_SETTINGS = {
    'app_name'        : C.get('RABBITMQ', 'APP_NAME'),
    'amq_host'        : C.get('RABBITMQ', 'HOST'),
    'amq_user'        : C.get('RABBITMQ', 'USER'),
    'amq_password'    : C.get('RABBITMQ', 'PASSWORD'),
    'amq_num_queues'  : int(C.get('RABBITMQ', 'QUEUES')),
    'amq_virtualhost' : C.get('RABBITMQ', 'VHOST'),
}

LIVE_SOCKET_PATH = C.get('ICINGA', 'LIVE')

# Logging
LOGGING_LEVEL    = C.get('LOGGING', 'LEVEL')
